@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,9 +16,7 @@ InvalidFilterInfoWidget::InvalidFilterInfoWidget(QWidget *parent)
     setWordWrap(true);
 }
 
-InvalidFilterInfoWidget::~InvalidFilterInfoWidget()
-{
-}
+InvalidFilterInfoWidget::~InvalidFilterInfoWidget() = default;
 
 void InvalidFilterInfoWidget::slotShowDetails(const QString &details)
 {
