@@ -1,6 +1,6 @@
 /*
 
-  SPDX-FileCopyrightText: 2010-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2010-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,17 +13,13 @@
 #include <Akonadi/AgentManager>
 #include <Akonadi/Collection>
 #include <Akonadi/EntityTreeModel>
-#include <Akonadi/KMime/SpecialMailCollections>
-
-#include <QRegularExpression>
+#include <Akonadi/SpecialMailCollections>
 
 using namespace MailCommon;
 class Q_DECL_HIDDEN MailCommon::EntityCollectionOrderProxyModel::EntityCollectionOrderProxyModelPrivate
 {
 public:
-    EntityCollectionOrderProxyModelPrivate()
-    {
-    }
+    EntityCollectionOrderProxyModelPrivate() = default;
 
     int collectionRank(const Akonadi::Collection &collection)
     {
